<cfcomponent 
	displayname="baseCHECKS" 
	hint="elementi comuni a tutti i check"
>

<cfscript>init();</cfscript>

<!--- 
	DEBUG: esegue un dump anche da cfscript
--->
<cffunction name="dumpMe" access="private" returntype="void">
	<cfargument name="myDump" type="any" required="yes">
	<cfdump var="#ARGUMENTS.myDump#">
</cffunction>


<!--- 
	CTRL: controlla che due liste abbiano un elemento in comune 
--->
<cffunction name="isListMatch" access="public" returntype="boolean">
	<cfargument name="L1" type="string" required="yes">
	<cfargument name="L2" type="string" required="yes">

	<cfscript>
		MyRet=false;
		if ( (ARGUMENTS.L1 IS "") OR (ARGUMENTS.L2 IS "") ) {
			MyRet=true;
		} else { 
			L=listLen(ARGUMENTS.L1);
			for (i=1; i LTE L; i++) {
				if ( ListContainsNoCase( ARGUMENTS.L2, listGetAt( ARGUMENTS.L1, i ) ) NEQ 0  ) MyRet=true;
			}
		}
		return( MyRet );	
	</cfscript>

</cffunction>


<!---
	UTILS: in una lista di parametri, controlla che ci siano tutti quelli obbligatori
--->
<cffunction name="mandatoryParamsCK" access="public" returntype="boolean">
	<cfargument name="ck" type="struct" required="yes">
	<cfargument name="pList" type="string" required="yes">

	<cfscript>
		myFound=TRUE;
		cList=structKeyList(ARGUMENTS.ck);
		for ( pj=1; pj LTE listLen(ARGUMENTS.pList); pj++) {
			myParam=listGetAt(ARGUMENTS.pList, pj);
			if (ListContainsNoCase(cList, myParam) IS 0) {
				SESSION.mixForms.sysErrObj.write("missing mandatory ["& myParam &"] param in CK [" & ARGUMENTS.ck.type & "]");	
				myFound=FALSE;
			}
		}	
		return( myFound );
	</cfscript>	
	
</cffunction>


<!---
	UTILS: controlla che:
		* un CK sia riconosciuto
		* abbia tutti i parametri obbligatori
		* abbia tutti i parametri validi
		successivamente questi controlli si daranno per gia' fatti
--->
<cffunction name="syntaxCK" access="public" returntype="boolean">
	<cfargument name="ck" type="struct" required="yes">

	<cfscript>
		myRet=TRUE;
		switch( ARGUMENTS.ck.type ) {
			
			// WRITE CK --------------------------------------------------------------------------------

			// <ck type="okFlag" list="A,B" />
			case "okFlag": myRet=mandatoryParamsCK(ARGUMENTS.ck, "list");	break;

			// <ck type="noFlag" list="A,B" />
			case "noFlag": myRet=mandatoryParamsCK(ARGUMENTS.ck, "list");	break;
			
			// <ck type="okLang" list="it,en" />
			case "okLang": myRet=mandatoryParamsCK(ARGUMENTS.ck, "list");	break;
				
			// <ck type="noLang" list="it,en" />
			case "noLang": myRet=mandatoryParamsCK(ARGUMENTS.ck, "list");	break;
			
			// <ck type="beginDate" date="31/12/2010" />
			case "beginDate":
				myRet=mandatoryParamsCK(ARGUMENTS.ck, "date");
				if ( myRet AND NOT LSIsDate( ARGUMENTS.ck.date ) ) {
					SESSION.formSysErrObj.write( "CK beginDate invalid: passed value [" & ARGUMENTS.ck.date & "] is not a date");
					myRet=FALSE;
				}
			break;

			// <ck type="endDate" date="31/12/2010" />
			case "endDate":
				myRet=mandatoryParamsCK(ARGUMENTS.ck, "date");
				if ( myRet AND NOT LSIsDate( ARGUMENTS.ck.date ) ) {
					SESSION.formSysErrObj.write( "CK endDate invalid: passed value [" & ARGUMENTS.ck.date & "] is not a date");
					myRet=FALSE;
				}
			break;

			// DATA CK ---------------------------------------------------------------------------------

			// <ck type="notNull" /> e senza parametri in generale
			case "notNull": break;
			case "isNumber": break;
			case "isCF": break;
			case "isIVA": break;
			case "isIVAorCF": break;
			case "isCAP": break;
			case "isMail": break;
			case "isTelefono": break;
			case "isDataMix": break;
			case "isON": break;

			// <ck type="notThisNumber" number="10" />
			case "notThisNumber":
				myRet=mandatoryParamsCK(ARGUMENTS.ck, "number");
				if ( myRet AND NOT isNumeric( ARGUMENTS.ck.number ) ) {
					SESSION.formSysErrObj.write( "CK number invalid: passed value [" & ARGUMENTS.ck.number & "] is not a number");
					myRet=FALSE;
				}
			break;

			// <ck type="notThisVal" option="pippo" />
			case "notThisVal": myRet=mandatoryParamsCK(ARGUMENTS.ck, "val");	break;

			// <ck type="notThisOption" option="pippo" />
			case "notThisOption": myRet=mandatoryParamsCK(ARGUMENTS.ck, "option");	break;

			// ERRORE: tipo di CK non riconosciuto -----------------------------------------------------
			default: 
				SESSION.mixForms.sysErrObj.write( "CHECK type ["& ARGUMENTS.ck.type & "] is unknown" ); 
				myRet=FALSE;
			break;
			
		}//END Switch
		
		return(myRet);
	</cfscript>
	
</cffunction>



<!---
	UTILS: cicla per eseguire struct CK dall'ARRAY gia' controllato e corretto
--->
<cffunction name="runCKS" access="public" returntype="boolean">
	<cfargument name="myVal" type="string" required="no" default="">
	<cfargument name="myKey" type="string" required="no" default="">

	<cfscript>
		// importa key e val; non serve per controlli "write" (che non hanno key e val)
		THIS.value=ARGUMENTS.myVal;
		THIS.key=ARGUMENTS.myKey;
		// estrae righe dal file xml e cicla per eseguire tutti i controlli
		myDecision=TRUE;
		//dumpme(ctrlArray);
		for (v=1; v LTE ArrayLen(THIS.ckArray); v++) {
			// se non viene fatto il passaggio nella tmp si incasina (sa solo lui perche')
			myDecision=myDecision AND isCheckOK( THIS.ckArray[v] );
		}
		return( myDecision );
	</cfscript>

</cffunction>




<!---
	COSTRUTTORE: estrae righe CK dal file xml e cicla per eseguire tutti i controlli
--->
<cffunction name="setup" access="public" returntype="void">
	<cfargument name="cksXML" type="xml" required="yes">
	<cfargument name="myLang" type="string" required="yes">
	<cfargument name="myFL" type="string" required="yes">

	<cfscript>
		// Si suppone che lang e FL siano gia' state vagliate e date per buone
		THIS.lang=ARGUMENTS.myLang;
		THIS.FL=ARGUMENTS.myFL;
		//controlla che ci sia lameno un ck
		if (isDefined("ARGUMENTS.cksXML.XmlChildren")) {
			// estrae righe dal file xml e cicla per eseguire tutti i controlli
			tmpArray=ARGUMENTS.cksXML.XmlChildren;
			tmpLen=arrayLen( tmpArray );
			//dumpme(ctrlArray);
			k=1;
			for (j=1; j LTE tmpLen; j++) {
				tmpStruct=tmpArray[j].XmlAttributes;
				if ( syntaxCK(tmpStruct) )	{ THIS.ckArray[k] = tmpStruct; k++; }
			}
		}
	</cfscript>

</cffunction>


<!---
	COSTRUTTORE: setta i valori di inizializzazione
--->
<cffunction name="init" access="private" returntype="void">
	<cfscript>
		THIS.ckArray=arrayNew(1);
		THIS.lang="";
		THIS.FL="";
		THIS.value="";
		THIS.key="";
	</cfscript>
</cffunction>

</cfcomponent>